@@ -1,6 +1,6 @@
 package Bio::Medpost::Var;
 
-our $medpost_path = '...............';
+our $medpost_path = '.....';
 
 use File::Spec::Functions;
 our $medpost_script = catfile($medpost_path, 'medpost');
